@@ -23,6 +23,7 @@ from __future__ import division
 
 import io
 import collections
+import enum
 import re
 import threading
 import time
@@ -82,12 +83,31 @@ class MigrationLimitExceeded(RuntimeError):
     """
 
 
-class PostCopyPhase:
+class PostCopyPhase(enum.IntEnum):
     NONE = 0
     REQUESTED = 1
     RUNNING = 2
 
 
+class State(enum.IntEnum):
+
+    # Migration thread was created and initialized. The next state is PREPARED
+    # under normal circumstances. If anything fails, next state is FAILED.
+    INITIALIZED = 0
+
+    # Set right before defining VM on the destination host. Next state is
+    # STARTED.
+    PREPARED = 1
+
+    # VM on the destination host was created and migration is about to start.
+    # If anything fails, next state is FAILED. If everything goes well,
+    # currently there's no other state.
+    STARTED = 2
+
+    # Migration failed. Final state.
+    FAILED = 3
+
+
 @virdomain.expose(
     "migrateToURI3",
     "migrateSetMaxSpeed",
@@ -161,8 +181,7 @@ class SourceThread(object):
                           self._convergence_schedule)
         self.log.debug('convergence schedule set to: %s',
                        str(self._convergence_schedule))
-        self._started = False
-        self._failed = False
+        self._state = State.STARTED if recovery else State.INITIALIZED
         self._recovery = recovery
         tunneled = conv.tobool(tunneled)
         abortOnError = conv.tobool(abortOnError)
@@ -190,18 +209,31 @@ class SourceThread(object):
         managed migration (detected on Vdsm recovery) without the threads
         actually running.
         """
-        return ((self.is_alive() and not self._failed) or
+        return ((self.is_alive() and self._state != State.FAILED) or
                 (self._recovery and
                  self._vm.lastStatus == vmstatus.MIGRATION_SOURCE))
 
+    def needs_disk_refresh(self):
+        """
+        Return True if migrating to destination host, and the migration
+        reached the state when remote disks must be refreshed during extend
+        disk flow.
+        """
+        return State.PREPARED <= self._state < State.FAILED
+
     @property
     def started(self):
-        return self._started
+        return self._state == State.STARTED
 
     @property
     def hibernating(self):
         return self._mode == MODE_FILE
 
+    def _switch_state(self, value):
+        if value != self._state:
+            self.log.info("Switching from %s to %s", self._state, value)
+            self._state = value
+
     def _update_progress(self):
         if self._monitorThread is None:
             return
@@ -315,13 +347,12 @@ class SourceThread(object):
         elif self._enableGuestEvents:
             self._vm.guestAgent.events.after_migration_failure()
         # either way, migration has finished
-        self._failed = True
+        self._switch_state(State.FAILED)
         if self._recovery:
             self._vm.set_last_status(vmstatus.UP, vmstatus.MIGRATION_SOURCE)
             self._recovery = False
         else:
             self._vm.lastStatus = vmstatus.UP
-        self._started = False
         self._vm.send_status_event()
 
     def _finishSuccessfully(self, machineParams):
@@ -424,7 +455,7 @@ class SourceThread(object):
             self._setupVdsConnection()
             self._prepareGuest()
 
-            while not self._started:
+            while not self.started:
                 try:
                     self.log.info("Migration semaphore: acquiring")
                     with SourceThread.ongoingMigrations:
@@ -477,10 +508,11 @@ class SourceThread(object):
 
     def _startUnderlyingMigration(self, startTime, machineParams):
         if self.hibernating:
-            self._started = True
+            self._switch_state(State.STARTED)
             self._vm.hibernate(self._dst)
         else:
             self._vm.prepare_migration()
+            self._switch_state(State.PREPARED)
 
             # Do not measure the time spent for creating the VM on the
             # destination. In some cases some expensive operations can cause
@@ -502,7 +534,7 @@ class SourceThread(object):
                         'migration destination error: ' +
                         result['status']['message'])
 
-            self._started = True
+            self._switch_state(State.STARTED)
 
             # REQUIRED_FOR: destination Vdsm < 4.3
             if not self._vm.min_cluster_version(4, 3):
@@ -721,7 +753,8 @@ class SourceThread(object):
 
         result = self._destServer.refresh_disk(self._vm.id, vol_pdiv)
         if response.is_error(result):
-            raise exception.CannotRefreshDisk(reason=result["message"])
+            raise exception.CannotRefreshDisk(
+                reason=result["status"]["message"])
         return VolumeSize(int(result["apparentsize"]), int(result["truesize"]))
 
 
